Welcome to the Pants build system.
==================================

Pants is a build system for software projects in a variety of
languages. It works particularly well for a source code repository
that contains many distinct projects.

Getting started using Pants
---------------------------

Tutorials and basic concepts. How to use Pants to build things.
How to configure build-able things in BUILD files.

.. toctree::
   :maxdepth: 1

   first_concepts
   first_tutorial
   target_addresses
   JVMProjects
   python-readme
   build_files
   invoking

Troubleshooting
---------------

* Something that usually works just failed? See :ref:`tshoot`.

* Publishing can fail in more ways. See :doc:`publish`.

Pants Patterns
--------------

Common Pants build idioms.

.. toctree::
   :maxdepth: 1

   3rdparty
   ThriftDeps
   publish

Advanced Documentation
----------------------

.. toctree::
   :maxdepth: 1

   setup_repo
   install
   README
   migration


Pants Reference Documentation
-----------------------------

.. toctree::
   :maxdepth: 1

   build_dictionary
   goals_reference
   targets
   tasks
   base

Contributing to Pants
---------------------

How to develop Pants itself and contribute your changes.

.. toctree::
   :maxdepth: 1

   howto_develop
   howto_contribute
   internals
   dev_tasks
   docs
   credits


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
